#
# spec file for package f2fs-tools
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           f2fs-tools
Version:        1.7.0
Release:        lp151.2.4
Summary:        Utilities for the Flash-friendly Filesystem (F2FS)
License:        GPL-2.0 and LGPL-2.1
Group:          System/Filesystems
Url:            https://git.kernel.org/cgit/linux/kernel/git/jaegeuk/f2fs-tools.git
Source:         %name-%version.tar.xz
Patch1:         f2fs-tools-1.4.0-bigendian.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(uuid)
Supplements:    filesystem(f2fs)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Utilities needed to create and maintain so-called Flash-Friendly (F2)
filesystems.

%package -n libf2fs1
Summary:        Library to manipulate F2 filesystems
Group:          System/Libraries

%description -n libf2fs1
This package contains a shared library used for manipulation of F2
filesystems.

%package -n libf2fs_format0
Summary:        Library to create F2 filesystems
Group:          System/Libraries

%description -n libf2fs_format0
This package contains a shared library to format F2 filesystems.

%package compat
Summary:        f2fs utility compatibility symlinks
Group:          System/Filesystem
BuildArch:      noarch

%description compat
This subpackage contains symbolic links /sbin/fsck.* and /sbin/mkfs.*
needed for programs that assume these locations.

%package devel
Summary:        Development files for f2fs
Group:          Development/Languages/C and C++
Requires:       libf2fs1 = %version
Requires:       libf2fs_format0 = %version

%description devel
This package contains development files for %name.

%prep
%setup -q
%patch -P 1 -p1

%build
autoreconf -fiv
%configure --disable-static
make %{?_smp_mflags}

%install -p /bin/bash
%make_install
find %buildroot -type f -name "*.la" -delete -print

mkdir -p "%buildroot/sbin" "%buildroot/%_includedir"
ln -sf "%_sbindir"/{defrag.f2fs,dump.f2fs,f2fstat,fibmap.f2fs,fsck.f2fs,mkfs.f2fs,parse.f2fs,resize.f2fs,sload.f2fs} "%buildroot/sbin/"
# for android-tools… this is of course totally untested.
# The shared library for example has a "main" symbol :-/
cp -a include/f2fs_fs.h mkfs/f2fs_format_utils.h \
	"%buildroot/%_includedir/"

%post   -n libf2fs1 -p /sbin/ldconfig
%postun -n libf2fs1 -p /sbin/ldconfig
%post   -n libf2fs_format0 -p /sbin/ldconfig
%postun -n libf2fs_format0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING
%_sbindir/*
%_mandir/man8/*

%files -n libf2fs1
%defattr(-,root,root)
%_libdir/libf2fs.so.*

%files -n libf2fs_format0
%defattr(-,root,root)
%_libdir/libf2fs_format.so.*

%files compat
%defattr(-,root,root)
/sbin/*

%files devel
%defattr(-,root,root)
%_includedir/*.h
%_libdir/libf2fs*.so

%changelog
* Sun Aug 28 2016 jengelh@inai.de
- Trim filelists, update descriptions, move symlink collection into
  their own subpackage.
* Sun Aug 28 2016 mpluskal@suse.com
- Update to version 1.7:
  * mkfs: define DISCARD/SECDISCARD macro
  * dump.f2fs: show inode->i_dir_level
  * f2fs.fsck: fix endianess
  * fsck.f2fs: correct variable type and name
  * fsck.f2fs: fix typo
  * fsck.f2fs: free nat entry cache
  * f2fs-tools: update the format of output message
  * fsck.f2fs: clean up duplicated code
  * fsck: recover symlink with zero i_size
  * f2fs-tools: release 1.7.0
- Add f2fs-tools-1.4.0-bigendian.patch (from Fedora)
- Use _service to fetch release from upstream git
- Split lib packages and create devel package (as andoid tools
  need it)
- Link binaries from /usr/sbin to /sbin, many tools expect fsck
  and friends to be in /sbin
- Supplement f2fs filesystem
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream release 1.6.0
  * Add a defrag utility
* Sat Mar 28 2015 jengelh@inai.de
- Update to new upstream release 1.4.1
  * fsck: remove corrupted data indices in direct node blocks
  * fsck/mkfs: support large sector size
  * parse.f2fs: add a tool to parse IO traces made by runtime f2fs
  * fsck: show orphan inodes when fixing partition
- Drop 0001-build-provide-definitions-for-byteswapping-on-big-en.patch
  (merged)
* Tue Sep 23 2014 jengelh@inai.de
- Replace 0001-build-provide-definitions-for-byteswapping-on-big-en.patch
  with official upstream version.
* Fri Sep 19 2014 jengelh@inai.de
- Update to new upstream release 1.4.0
  * fsck: add the -a option (auto-fix errors) [bnc#856645]
  * fsck: remove corrupted xattr blocks and corrupted orphan inodes;
  remove dentry if inode block is corrupted
- Add 0001-build-provide-definitions-for-byteswapping-on-big-en.patch
* Fri Jul 18 2014 jengelh@inai.de
- Update to new snapshot 1.3.0.g22
  * add "f2fstat" program to print f2fs's status in sec
  * mkfs: support large directories
  * mkfs.f2fs, fsck.f2fs: large volume support
* Sun Nov 24 2013 jengelh@inai.de
- Update to new upstream release 1.2.0
  * f2fs-tools: add stat information into fibmap
  * fibmap.f2fs: change fibmap to fibmap.f2fs
  * fsck, lib: support inline xattr
  * fsck: skip to check block addresses in device files
  * fsck: fix to handle file types correctly
  * fsck: fix checking orphan inodes
* Wed Aug  7 2013 jengelh@inai.de
- Update to new snapshot v1.1.0-40-g6e8f2d5
  * Correct endianess conversions for CRC calculations, checkpoint
  flags and in f2fs_update_nat_root.
  * Fix the total_zones calculation in f2fs_prepare_super_block
  * Add the fsck.f2fs and dump.f2fs utilities
* Mon Jun 10 2013 jengelh@inai.de
- Update to new snapshot v1.1.0-24-gfef98eb
  * mkfs: add option to disable trim at format
  * mkfs: handle labels longer than 16 characters
* Mon Jan 21 2013 jengelh@inai.de
- Add COPYING file to package
* Wed Dec 12 2012 jengelh@inai.de
- Initial package (version v1.1.0-11-gc7e0a01) for build.opensuse.org
